# `prefect-dask`

<p align="center">
    <a href="https://pypi.python.org/pypi/prefect-dask/" alt="PyPI version">
        <img alt="PyPI" src="https://img.shields.io/pypi/v/prefect-dask?color=26272B&labelColor=090422"></a>
    <a href="https://pepy.tech/badge/prefect-dask/" alt="Downloads">
        <img src="https://img.shields.io/pypi/dm/prefect-dask?color=26272B&labelColor=090422" /></a>
</p>

See the docs at [https://docs.prefect.io/integrations/prefect-dask](https://docs.prefect.io/integrations/prefect-dask) for more information.
